@@ -345,7 +345,7 @@ get_password_cb (GObject *source,
 {
   ObserveChannelsData *data = user_data;
 
-  if (empathy_keyring_get_password_finish (TP_ACCOUNT (source), result, NULL) == NULL)
+  if (empathy_keyring_get_account_password_finish (TP_ACCOUNT (source), result, NULL) == NULL)
     {
       /* We don't actually mind if this fails, just let the approver
        * go ahead and take the channel. */
@@ -404,7 +404,7 @@ observe_channels (TpBaseClient *client,
   data->account = g_object_ref (account);
   data->channel = g_object_ref (channel);
 
-  empathy_keyring_get_password_async (account, get_password_cb, data);
+  empathy_keyring_get_account_password_async (account, get_password_cb, data);
 
   tp_observe_channels_context_delay (context);
 }
@@ -489,8 +489,6 @@ empathy_auth_factory_constructed (GObject *obj)
           TP_PROP_CHANNEL_TYPE_SERVER_AUTHENTICATION_AUTHENTICATION_METHOD,
           G_TYPE_STRING, TP_IFACE_CHANNEL_INTERFACE_SASL_AUTHENTICATION,
           NULL));
-
-  tp_base_client_set_observer_delay_approvers (client, TRUE);
 }
 
 static void
