@@ -30,7 +30,6 @@
 
 #include "empathy-ft-handler.h"
 #include "empathy-tp-contact-factory.h"
-#include "empathy-dispatcher.h"
 #include "empathy-marshal.h"
 #include "empathy-time.h"
 #include "empathy-utils.h"
@@ -125,8 +124,6 @@ typedef struct {
   GCancellable *cancellable;
   gboolean use_hash;
 
-  EmpathyDispatcher *dispatcher;
-
   /* request for the new transfer */
   GHashTable *request;
 
@@ -276,12 +273,6 @@ do_dispose (GObject *object)
       priv->request = NULL;
     }
 
-  if (priv->dispatcher != NULL)
-    {
-      g_object_unref (priv->dispatcher);
-      priv->dispatcher = NULL;
-    }
-
   G_OBJECT_CLASS (empathy_ft_handler_parent_class)->dispose (object);
 }
 
@@ -544,7 +535,6 @@ empathy_ft_handler_init (EmpathyFTHandler *self)
 
   self->priv = priv;
   priv->cancellable = g_cancellable_new ();
-  priv->dispatcher = empathy_dispatcher_dup_singleton ();
 }
 
 /* private functions */
@@ -774,8 +764,10 @@ ft_handler_populate_outgoing_request (EmpathyFTHandler *handler)
 {
   guint contact_handle;
   EmpathyFTHandlerPriv *priv = GET_PRIV (handler);
+  gchar *uri;
 
   contact_handle = empathy_contact_get_handle (priv->contact);
+  uri = g_file_get_uri (priv->gfile);
 
   priv->request = tp_asv_new (
       TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
@@ -792,7 +784,10 @@ ft_handler_populate_outgoing_request (EmpathyFTHandler *handler)
         priv->total_bytes,
       TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_DATE, G_TYPE_UINT64,
         priv->mtime,
+      TP_PROP_CHANNEL_TYPE_FILE_TRANSFER_URI, G_TYPE_STRING, uri,
       NULL);
+
+  g_free (uri);
 }
 
 static gboolean
