@@ -118,6 +118,7 @@ account_manager_ready_for_accounts_cb (GObject *source_object,
       if ((account = tp_account_new (bus, account_path, &error)))
         {
           tp_account_prepare_async (account, NULL, account_prepare_cb, manager);
+          g_object_unref (bus);
           return;
         }
       else
@@ -231,6 +232,8 @@ main (int argc, char *argv[])
 
   g_set_application_name (_("Empathy Accounts"));
 
+  /* Make empathy and empathy-accounts appear as the same app in gnome-shell */
+  gdk_set_program_class ("Empathy");
   gtk_window_set_default_icon_name ("empathy");
   textdomain (GETTEXT_PACKAGE);
 
